@@ -10,7 +10,7 @@ Unless required by applicable law or agreed to in writing, software distributed
 an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 specific language governing permissions and limitations under the License.
 """
-
+import os
 import django
 from django.conf import settings
 
@@ -28,7 +28,7 @@ def get_wsgi_application():
     """
     django.setup(set_prefix=False)
 
-    if "blueapps.opentelemetry.instrument_app" in set(settings.INSTALLED_APPS):
+    if os.getenv("ENABLE_METRICS") or getattr(settings, "ENABLE_OTEL_METRICS", False):
         start_metrics_http_server()
 
     return BkWSGIHandler()
