@@ -59,19 +59,34 @@ def setup_trace_config(
 
 
 def setup_by_settings():
-    enable_trace = os.getenv("ENABLE_TRACE", False) or getattr(settings, "ENABLE_OTEL_TRACE", False)
+    enable_paas_otel = True if getattr(settings, "OTEL_BK_DATA_TOKEN", "") else False
+    enable_trace = os.getenv("ENABLE_TRACE", enable_paas_otel) or getattr(
+        settings, "ENABLE_OTEL_TRACE", enable_paas_otel
+    )
     if enable_trace:
+        app_module_name = getattr(settings, "APP_MODULE_NAME", "")
         service_name = (
             os.getenv("BKAPP_OTEL_SERVICE_NAME")
             or getattr(settings, "BKAPP_OTEL_SERVICE_NAME", None)
-            or settings.APP_CODE
+            or (settings.APP_CODE + f"-{app_module_name}" if app_module_name else "")
         )
         bk_data_id = int(os.getenv("BKAPP_OTEL_BK_DATA_ID") or getattr(settings, "BKAPP_OTEL_BK_DATA_ID", -1))
         otel_sampler = (
-            os.getenv("BKAPP_OTEL_SAMPLER") or getattr(settings, "BKAPP_OTEL_SAMPLER", None) or "parentbased_always_off"
+            os.getenv("BKAPP_OTEL_SAMPLER")
+            or getattr(settings, "BKAPP_OTEL_SAMPLER", None)
+            or getattr(settings, "OTEL_SAMPLER", None)
+            or "parentbased_always_off"
+        )
+        otel_grpc_host = (
+            os.getenv("BKAPP_OTEL_GRPC_HOST")
+            or getattr(settings, "BKAPP_OTEL_GRPC_HOST", None)
+            or getattr(settings, "OTEL_GRPC_HOST", None)
+        )
+        otel_bk_data_token = (
+            os.getenv("BKAPP_OTEL_BK_DATA_TOKEN")
+            or getattr(settings, "BKAPP_OTEL_BK_DATA_TOKEN", "")
+            or getattr(settings, "OTEL_BK_DATA_TOKEN", "")
         )
-        otel_grpc_host = os.getenv("BKAPP_OTEL_GRPC_HOST") or getattr(settings, "BKAPP_OTEL_GRPC_HOST", None)
-        otel_bk_data_token = os.getenv("BKAPP_OTEL_BK_DATA_TOKEN") or getattr(settings, "BKAPP_OTEL_BK_DATA_TOKEN", "")
         setup_trace_config(
             service_name, bk_data_id, otel_sampler, otel_grpc_host, bk_data_token=otel_bk_data_token,
         )
